@@ -1,20 +1,20 @@
 # -*- coding: utf-8 -*-
-# Copyright 2007-2011 The Hyperspy developers
+# Copyright 2007-2011 The HyperSpy developers
 #
-# This file is part of  Hyperspy.
+# This file is part of  HyperSpy.
 #
-#  Hyperspy is free software: you can redistribute it and/or modify
+#  HyperSpy is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
-#  Hyperspy is distributed in the hope that it will be useful,
+#  HyperSpy is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with  Hyperspy.  If not, see <http://www.gnu.org/licenses/>.
+# along with  HyperSpy.  If not, see <http://www.gnu.org/licenses/>.
 
 #  for more information on the RPL/RAW format, see
 #  http://www.nist.gov/lispix/
@@ -27,9 +27,9 @@ from StringIO import StringIO
 
 import numpy as np
 
-from hyperspy.misc.utils_readfile import *
+from hyperspy.misc.io.utils_readfile import *
 from hyperspy import Release
-from hyperspy.misc.utils import DictionaryBrowser
+from hyperspy.misc.utils import DictionaryTreeBrowser
 
 # Plugin characteristics
 # ----------------------
@@ -38,12 +38,12 @@ description = 'RPL file contains the information on how to read\n'
 description += 'the RAW file with the same name.'
 description += '\nThis format may not provide information on the calibration.'
 description += '\nIf so, you should add that after loading the file.'
-full_suport = False             #  but maybe True
+full_suport = False  # but maybe True
 # Recognised file extension
-file_extensions = ['rpl','RPL']
+file_extensions = ['rpl', 'RPL']
 default_extension = 0
 # Writing capabilities
-writes = [(1,0), (1,1), (1,2), (2,0), (2,1),]
+writes = [(1, 0), (1, 1), (1, 2), (2, 0), (2, 1), ]
 # ----------------------
 
 # The format only support the followng data types
@@ -52,100 +52,118 @@ comment = ';'
 sep = '\t'
 
 dtype2keys = {
-                'float64' : ('float', 8),
-                'float32' : ('float', 4),
-                'uint8' : ('unsigned', 1),
-                'uint16' : ('unsigned', 2),
-                'int32' : ('signed', 4),
-                'int64' : ('signed', 8),}
+    'float64': ('float', 8),
+    'float32': ('float', 4),
+    'uint8': ('unsigned', 1),
+    'uint16': ('unsigned', 2),
+    'int32': ('signed', 4),
+    'int64': ('signed', 8), }
 
 endianess2rpl = {
-                    '=' : 'dont-care',
-                    '<' : 'little-endian',
-                    '>' : 'big-endian'}
+    '=': 'dont-care',
+    '<': 'little-endian',
+    '>': 'big-endian'}
 
 rpl_keys = {
     # spectrum/image keys
-    'width' : int,
-    'height' : int,
-    'depth' : int,
-    'offset': int ,
-    'data-length' : ['1', '2', '4', '8'],
-    'data-type' : ['signed', 'unsigned', 'float'],
-    'byte-order' : ['little-endian', 'big-endian', 'dont-care'],
-    'record-by' : ['image', 'vector', 'dont-care'],
+    'width': int,
+    'height': int,
+    'depth': int,
+    'offset': int,
+    'data-length': ['1', '2', '4', '8'],
+    'data-type': ['signed', 'unsigned', 'float'],
+    'byte-order': ['little-endian', 'big-endian', 'dont-care'],
+    'record-by': ['image', 'vector', 'dont-care'],
     # X-ray keys
-    'ev-per-chan' : float,    # usually 5 or 10 eV
-    'detector-peak-width-ev' : float, # usually 150 eV
-    # Hyperspy-specific keys
-    'depth-origin' : float,
-    'depth-scale' : float,
-    'depth-units' : unicode,
-    'width-origin' : float,
-    'width-scale' : float,
-    'width-units' : unicode,
-    'height-origin' : float,
-    'height-scale' : float,
-    'height-units' : unicode,
-    'signal' : unicode,
-    # EELS Hyperspy keys
-    'collection-angle' : float,
+    'ev-per-chan': float,    # usually 5 or 10 eV
+    'detector-peak-width-ev': float,  # usually 150 eV
+    # HyperSpy-specific keys
+    'depth-origin': float,
+    'depth-scale': float,
+    'depth-units': unicode,
+    'width-origin': float,
+    'width-scale': float,
+    'width-units': unicode,
+    'height-origin': float,
+    'height-scale': float,
+    'height-units': unicode,
+    'signal': unicode,
+    # EELS HyperSpy keys
+    'collection-angle': float,
     # TEM Hyperespy keys
-    'convergence-angle' : float,
-    'beam-energy' : float,
-    }
+    'convergence-angle': float,
+    'beam-energy': float,
+    # EDS Hyperespy keys
+    'elevation-angle': float,
+    'azimuth-angle': float,
+    'live-time': float,
+    'energy-resolution': float,
+    'tilt-stage': float,
+}
+
 
 def correct_INCA_format(fp):
     fp_list = list()
-    fp.seek(0)    
+    fp.seek(0)
     if '(' in fp.readline():
         for line in fp:
-            line=line.replace("(MLX::","").replace(" : ", "\t").replace(" :", "\t").replace(" ","\t").lower().strip().replace(")","\n")
+            line = line.replace(
+                "(MLX::",
+                "").replace(
+                " : ",
+                "\t").replace(
+                " :",
+                "\t").replace(
+                " ",
+                "\t").lower().strip().replace(
+                ")",
+                "\n")
             if "record-by" in line:
                 if "image" in line:
                     line = "record-by\timage"
                 if "vector" in line:
                     line = "record-by\tvector"
                 if "dont-care" in line:
-                    line = "record-by\tdont-care"                    
+                    line = "record-by\tdont-care"
             fp_list.append(line)
         fp = StringIO()
         fp.writelines(fp_list)
     fp.seek(0)
     return fp
-            
+
 
 def parse_ripple(fp):
     """Parse information from ripple (.rpl) file.
     Accepts file object 'fp. Returns dictionary rpl_info.
     """
-    
 
     fp = correct_INCA_format(fp)
-                            
+
     rpl_info = {}
     for line in fp.readlines():
         line = line.replace(' ', '')
+        # correct_brucker_format
+        line = line.replace('data-Length', 'data-length')
         if line[:2] not in newline and line[0] != comment:
             line = line.strip('\r\n')
             #line = line.lower()
             if comment in line:
-                line = line[:line.find(comment)]           
+                line = line[:line.find(comment)]
             if not sep in line:
                 err = 'Separator in line "%s" is wrong, ' % line
                 err += 'it should be a <TAB> ("\\t")'
-                raise IOError, err
-            line = line.split(sep) # now it's a list
-            if rpl_keys.has_key(line[0]) is True:
+                raise IOError(err)
+            line = line.split(sep)  # now it's a list
+            if (line[0] in rpl_keys) is True:
                 # is rpl_keys[line[0]] an iterable?
-                if hasattr(rpl_keys[line[0]],'__iter__'):
+                if hasattr(rpl_keys[line[0]], '__iter__'):
                     if line[1] not in rpl_keys[line[0]]:
                         err = \
-                        'Wrong value for key %s.\n' \
-                        'Value read is %s'  \
-                        ' but it should be one of %s' % \
-                        (line[0], line[1], str(rpl_keys[line[0]]))
-                        raise IOError, err
+                            'Wrong value for key %s.\n' \
+                            'Value read is %s'  \
+                            ' but it should be one of %s' % \
+                            (line[0], line[1], str(rpl_keys[line[0]]))
+                        raise IOError(err)
                 else:
                     # rpl_keys[line[0]] must then be a type
                     line[1] = rpl_keys[line[0]](line[1])
@@ -157,23 +175,24 @@ def parse_ripple(fp):
         err += '"depth" cannot be "1" if "record-by" is "dont-care" '
         err += 'and vice versa.'
         err += 'Check %s' % fp.name
-        raise IOError, err
+        raise IOError(err)
     if rpl_info['data-type'] == 'float' and int(rpl_info['data-length']) < 4:
         err = '"data-length" for float "data-type" must be "4" or "8".\n'
         err += 'Check %s' % fp.name
-        raise IOError, err
+        raise IOError(err)
     if rpl_info['data-length'] == '1' and rpl_info['byte-order'] != 'dont-care':
         err = '"data-length" and "byte-order" mismatch.\n'
         err += '"data-length" cannot be "1" if "byte-order" is "dont-care" '
         err += 'and vice versa.'
         err += 'Check %s' % fp.name
-        raise IOError, err
+        raise IOError(err)
     return rpl_info
 
+
 def read_raw(rpl_info, fp, mmap_mode='c'):
     """Read the raw file object 'fp' based on the information given in the
     'rpl_info' dictionary.
-    
+
     Parameters
     ----------
     rpl_info: dict
@@ -188,8 +207,8 @@ def read_raw(rpl_info, fp, mmap_mode='c'):
     ndarray.  Memory mapping is especially useful for accessing
     small fragments of large files without reading the entire file
     into memory.
-    
-    
+
+
     """
     width = rpl_info['width']
     height = rpl_info['height']
@@ -207,7 +226,7 @@ def read_raw(rpl_info, fp, mmap_mode='c'):
     elif data_type == 'float':
         pass
     else:
-        raise TypeError, 'Unknown "data-type" string.'
+        raise TypeError('Unknown "data-type" string.')
 
     if endian == 'big-endian':
         endian = '>'
@@ -236,8 +255,9 @@ def read_raw(rpl_info, fp, mmap_mode='c'):
         data = data.reshape(size)
     return data
 
+
 def file_reader(filename, rpl_info=None, encoding="latin-1",
-                mmap_mode='c', *args,**kwds):
+                mmap_mode='c', *args, **kwds):
     """Parses a Lispix (http://www.nist.gov/lispix/) ripple (.rpl) file
     and reads the data from the corresponding raw (.raw) file;
     or, read a raw file if the dictionary rpl_info is provided.
@@ -261,10 +281,10 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
     Alternatively, dictionary 'rpl_info' containing the information can
     be given.
 
-    Some keys are specific to Hyperspy and will be ignored by other software.
+    Some keys are specific to HyperSpy and will be ignored by other software.
 
     RPL stands for "Raw Parameter List", an ASCII text, tab delimited file in
-    which Hyperspy reads the image parameters for a raw file.
+    which HyperSpy reads the image parameters for a raw file.
 
                     TABLE OF RPL PARAMETERS
         key             type     description
@@ -281,7 +301,7 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
       # X-ray keys:
       ev-per-chan      int      # optional, eV per channel
       detector-peak-width-ev  int   # optional, FWHM for the Mn K-alpha line
-      # Hyperspy-specific keys
+      # HyperSpy-specific keys
       depth-origin    int      # energy offset in pixels
       depth-scale     float    # energy scaling (units per pixel)
       depth-units     str      # energy units, usually eV
@@ -298,6 +318,11 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
       convergence-angle float   # TEM convergence angle in mrad
       collection-angle  float   # EELS spectrometer collection angle in mrad
       beam-energy       float   # TEM beam energy in keV
+      elevation-angle   float   # Elevation angle of the EDS detector
+      azimuth-angle     float   # Elevation angle of the EDS detector
+      live-time         float   # Live time per spectrum
+      energy-resolution float   # Resolution of the EDS (FHWM of MnKa)
+      tilt-stage       float   # The tilt of the stage
 
     NOTES
 
@@ -330,16 +355,16 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
     Other keys and values can be included and are ignored.
 
     Any number of spaces can go along with each tab.
-    
+
     """
-    
+
     if not rpl_info:
         if filename[-3:] in file_extensions:
-            with codecs.open(filename, encoding = encoding,
-                              errors = 'replace') as f:
+            with codecs.open(filename, encoding=encoding,
+                             errors='replace') as f:
                 rpl_info = parse_ripple(f)
         else:
-            raise IOError, 'File has wrong extension: "%s"' % filename[-3:]
+            raise IOError('File has wrong extension: "%s"' % filename[-3:])
     for ext in ['raw', 'RAW']:
         rawfname = filename[:-3] + ext
         if os.path.exists(rawfname):
@@ -347,7 +372,7 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
         else:
             rawfname = ''
     if not rawfname:
-        raise IOError, 'RAW file "%s" does not exists' % rawfname
+        raise IOError('RAW file "%s" does not exists' % rawfname)
     else:
         data = read_raw(rpl_info, rawfname, mmap_mode=mmap_mode)
 
@@ -379,89 +404,106 @@ def file_reader(filename, rpl_info=None, encoding="latin-1",
 
     if 'signal' not in rpl_info:
         rpl_info['signal'] = ""
-        
-    if rpl_info.has_key('detector-peak-width-ev'):
-        original_parameters['detector-peak-width-ev'] = \
-        rpl_info['detector-peak-width-ev']
 
-    if rpl_info.has_key('depth-scale'):
+    if 'detector-peak-width-ev' in rpl_info:
+        original_metadata['detector-peak-width-ev'] = \
+            rpl_info['detector-peak-width-ev']
+
+    if 'depth-scale' in rpl_info:
         scales[idepth] = rpl_info['depth-scale']
     # ev-per-chan is the only calibration supported by the original ripple
     # format
-    elif rpl_info.has_key('ev-per-chan'):
+    elif 'ev-per-chan' in rpl_info:
         scales[idepth] = rpl_info['ev-per-chan']
 
-    if rpl_info.has_key('depth-origin'):
+    if 'depth-origin' in rpl_info:
         origins[idepth] = rpl_info['depth-origin']
 
-    if rpl_info.has_key('depth-units'):
+    if 'depth-units' in rpl_info:
         units[idepth] = rpl_info['depth-units']
 
-    if rpl_info.has_key('depth-name'):
+    if 'depth-name' in rpl_info:
         names[idepth] = rpl_info['depth-name']
 
-    if rpl_info.has_key('width-origin'):
+    if 'width-origin' in rpl_info:
         origins[iwidth] = rpl_info['width-origin']
 
-    if rpl_info.has_key('width-scale'):
+    if 'width-scale' in rpl_info:
         scales[iwidth] = rpl_info['width-scale']
 
-    if rpl_info.has_key('width-units'):
+    if 'width-units' in rpl_info:
         units[iwidth] = rpl_info['width-units']
 
-    if rpl_info.has_key('width-name'):
+    if 'width-name' in rpl_info:
         names[iwidth] = rpl_info['width-name']
 
-    if rpl_info.has_key('height-origin'):
+    if 'height-origin' in rpl_info:
         origins[iheight] = rpl_info['height-origin']
 
-    if rpl_info.has_key('height-scale'):
+    if 'height-scale' in rpl_info:
         scales[iheight] = rpl_info['height-scale']
 
-    if rpl_info.has_key('height-units'):
+    if 'height-units' in rpl_info:
         units[iheight] = rpl_info['height-units']
 
-    if rpl_info.has_key('height-name'):
+    if 'height-name' in rpl_info:
         names[iheight] = rpl_info['height-name']
-        
-    
-    mp = DictionaryBrowser({
-			'record_by': record_by,
-			'original_filename': os.path.split(filename)[1],
-            'signal_type': rpl_info['signal'],
-			})
-            
+
+    mp = DictionaryTreeBrowser({
+
+        'General': {'original_filename': os.path.split(filename)[1]},
+        "Signal": {'signal_type': rpl_info['signal'],
+                   'record_by': record_by, },
+    })
+
     if 'convergence-angle' in rpl_info:
-        mp.set_item('TEM.convergence_angle', 
-            rpl_info['convergence-angle'])
+        mp.set_item('Acquisition_instrument.TEM.convergence_angle',
+                    rpl_info['convergence-angle'])
+    if 'tilt-stage' in rpl_info:
+        mp.set_item('Acquisition_instrument.TEM.tilt_stage',
+                    rpl_info['tilt-stage'])
     if 'collection-angle' in rpl_info:
-        mp.set_item('TEM.EELS.collection_angle', 
-            rpl_info['collection-angle'])
+        mp.set_item('Acquisition_instrument.TEM.Detector.EELS.collection_angle',
+                    rpl_info['collection-angle'])
     if 'beam-energy' in rpl_info:
-        mp.set_item('TEM.beam_energy', 
-            rpl_info['beam-energy'])
+        mp.set_item('Acquisition_instrument.TEM.beam_energy',
+                    rpl_info['beam-energy'])
+    if 'elevation-angle' in rpl_info:
+        mp.set_item('Acquisition_instrument.TEM.Detector.EDS.elevation_angle',
+                    rpl_info['elevation-angle'])
+    if 'azimuth-angle' in rpl_info:
+        mp.set_item('Acquisition_instrument.TEM.Detector.EDS.azimuth_angle',
+                    rpl_info['azimuth-angle'])
+    if 'energy-resolution' in rpl_info:
+        mp.set_item('Acquisition_instrument.TEM.Detector.EDS.energy_resolution_MnKa',
+                    rpl_info['energy-resolution'])
+    if 'live-time' in rpl_info:
+        mp.set_item('Acquisition_instrument.TEM.Detector.EDS.live_time',
+                    rpl_info['live-time'])
+
     axes = []
     index_in_array = 0
     for i in xrange(3):
         if sizes[i] > 1:
             axes.append({
-                            'size' : sizes[i],
-                            'index_in_array' : index_in_array ,
-                            'name' : names[i],
-                            'scale': scales[i],
-                            'offset' : origins[i],
-                            'units' : units[i],
-                        })
+                'size': sizes[i],
+                'index_in_array': index_in_array,
+                'name': names[i],
+                'scale': scales[i],
+                'offset': origins[i],
+                'units': units[i],
+            })
             index_in_array += 1
 
     dictionary = {
         'data': data.squeeze(),
         'axes': axes,
-        'mapped_parameters': mp.as_dictionary(),
-        'original_parameters': rpl_info
-        }
+        'metadata': mp.as_dictionary(),
+        'original_metadata': rpl_info
+    }
     return [dictionary, ]
 
+
 def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
 
     # Set the optional keys to None
@@ -470,25 +512,25 @@ def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
     # Check if the dtype is supported
     dc = signal.data
     dtype_name = signal.data.dtype.name
-    if  dtype_name not in dtype2keys.keys():
+    if dtype_name not in dtype2keys.keys():
         err = 'The ripple format does not support writting data of %s type' % (
-        dtype_name)
-        raise IOError, err
+            dtype_name)
+        raise IOError(err)
     # Check if the dimensions are supported
     dimension = len(signal.data.shape)
-    if  dimension > 3:
+    if dimension > 3:
         err = 'This file format does not support %i dimension data' % (
-        dimension)
-        raise IOError, err
+            dimension)
+        raise IOError(err)
 
     # Gather the information to write the rpl
     data_type, data_length = dtype2keys[dc.dtype.name]
     byte_order = endianess2rpl[dc.dtype.byteorder.replace('|', '=')]
     offset = 0
-    if hasattr(signal.mapped_parameters,'signal_type'):
-        signal_type = signal.mapped_parameters.signal_type
+    if signal.metadata.has_item("Signal.signal_type"):
+        signal_type = signal.metadata.Signal.signal_type
     else:
-        signal_type=""
+        signal_type = ""
     if signal.axes_manager.signal_dimension == 1:
         record_by = 'vector'
         depth_axis = signal.axes_manager.signal_axes[0]
@@ -497,10 +539,10 @@ def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
             width_axis = signal.axes_manager.navigation_axes[0]
             height_axis = signal.axes_manager.navigation_axes[1]
             depth, width, height = \
-                            depth_axis.size, width_axis.size, height_axis.size
+                depth_axis.size, width_axis.size, height_axis.size
         elif dimension == 2:
             width_axis = signal.axes_manager.navigation_axes[0]
-            depth, width, height = depth_axis.size, width_axis.size,1
+            depth, width, height = depth_axis.size, width_axis.size, 1
         elif dimension == 1:
             record_by == 'dont-care'
             depth, width, height = depth_axis.size, 1, 1
@@ -512,7 +554,7 @@ def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
             depth_axis = signal.axes_manager.navigation_axes[0]
             record_by = 'image'
             depth, width, height =  \
-                            depth_axis.size, width_axis.size, height_axis.size
+                depth_axis.size, width_axis.size, height_axis.size
         elif dimension == 2:
             record_by = 'dont-care'
             width, height, depth = width_axis.size, height_axis.size, 1
@@ -525,16 +567,16 @@ def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
 
     # Fill the keys dictionary
     keys_dictionary = {
-                         'width' : width,
-                         'height' : height,
-                         'depth' : depth,
-                         'offset' : offset,
-                         'data-type' : data_type,
-                         'data-length' : data_length,
-                         'byte-order' : byte_order,
-                         'record-by' : record_by,
-                         'signal' : signal_type
-                         }
+        'width': width,
+        'height': height,
+        'depth': depth,
+        'offset': offset,
+        'data-type': data_type,
+        'data-length': data_length,
+        'byte-order': byte_order,
+        'record-by': record_by,
+        'signal': signal_type
+    }
     if ev_per_chan is not None:
         keys_dictionary['ev-per-chan'] = ev_per_chan
     keys = ['depth', 'height', 'width']
@@ -548,22 +590,42 @@ def file_writer(filename, signal, encoding='latin-1', *args, **kwds):
                 '%s_axis.units' % key)
             keys_dictionary['%s-name' % key] = eval(
                 '%s_axis.name' % key)
-            
-    mp = signal.mapped_parameters
-    if mp.has_item('TEM.beam_energy'):
-        keys_dictionary['beam-energy'] = mp.TEM.beam_energy
-    if mp.has_item('TEM.convergence_angle'):
-        keys_dictionary['convergence-angle'] = mp.TEM.convergence_angle
-    if mp.has_item('TEM.EELS.collection_angle'):
-        keys_dictionary['collection-angle'] = mp.TEM.EELS.collection_angle
+
+    if "EDS" in signal.metadata.Signal.signal_type:
+        if signal.metadata.Signal.signal_type == "EDS_SEM":
+            mp = signal.metadata.Acquisition_instrument.SEM
+        elif signal.metadata.Signal.signal_type == "EDS_TEM":
+            mp = signal.metadata.Acquisition_instrument.TEM
+
+        if mp.has_item('beam_energy'):
+            keys_dictionary['beam-energy'] = mp.beam_energy
+        if mp.has_item('convergence_angle'):
+            keys_dictionary['convergence-angle'] = mp.convergence_angle
+        if mp.has_item('Detector.EELS.collection_angle'):
+            keys_dictionary[
+                'collection-angle'] = mp.Detector.EELS.collection_angle
+
+        if mp.has_item('Detector.EDS.elevation_angle'):
+            keys_dictionary[
+                'elevation-angle'] = mp.Detector.EDS.elevation_angle
+        if mp.has_item('tilt_stage'):
+            keys_dictionary['tilt-stage'] = mp.tilt_stage
+        if mp.has_item('Detector.EDS.azimuth_angle'):
+            keys_dictionary['azimuth-angle'] = mp.Detector.EDS.azimuth_angle
+        if mp.has_item('Detector.EDS.live_time'):
+            keys_dictionary['live-time'] = mp.Detector.EDS.live_time
+        if mp.has_item('Detector.EDS.energy_resolution_MnKa'):
+            keys_dictionary[
+                'energy-resolution'] = mp.Detector.EDS.energy_resolution_MnKa
 
     write_rpl(filename, keys_dictionary, encoding)
     write_raw(filename, signal, record_by)
 
-def write_rpl(filename, keys_dictionary, encoding = 'ascii'):
-    f = codecs.open(filename, 'w', encoding = encoding,
-                    errors = 'ignore')
-    f.write(';File created by Hyperspy version %s\n' % Release.version)
+
+def write_rpl(filename, keys_dictionary, encoding='ascii'):
+    f = codecs.open(filename, 'w', encoding=encoding,
+                    errors='ignore')
+    f.write(';File created by HyperSpy version %s\n' % Release.version)
     f.write('key\tvalue\n')
     # Even if it is not necessary, we sort the keywords when writing
     # to make the rpl file more human friendly
@@ -573,6 +635,7 @@ def write_rpl(filename, keys_dictionary, encoding = 'ascii'):
         f.write(key + '\t' + value + '\n')
     f.close()
 
+
 def write_raw(filename, signal, record_by):
     """Writes the raw file object
 
@@ -591,16 +654,16 @@ def write_raw(filename, signal, record_by):
         if record_by == 'vector':
             np.rollaxis(
                 data, signal.axes_manager.signal_axes[0].index_in_array, 3
-                        ).ravel().tofile(filename)
+            ).ravel().tofile(filename)
         elif record_by == 'image':
             data = np.rollaxis(
                 data, signal.axes_manager.navigation_axes[0].index_in_array, 0
-                        ).ravel().tofile(filename)
+            ).ravel().tofile(filename)
     elif len(dshape) == 2:
         if record_by == 'vector':
             np.rollaxis(
                 data, signal.axes_manager.signal_axes[0].index_in_array, 2
-                        ).ravel().tofile(filename)
+            ).ravel().tofile(filename)
         elif record_by in ('image', 'dont-care'):
             data.ravel().tofile(filename)
     elif len(dshape) == 1:
