@@ -2,8 +2,4 @@ c = get_config()
 c.IPKernelApp.exec_lines = ['from hyperspy.hspy import *',
                             'import hyperspy.Release',
                             'print hyperspy.Release.info']
-c.IPKernelApp.pylab = "wx"
-
-
-
-
+c.IPKernelApp.pylab = "qt"
