@@ -1,21 +1,129 @@
 import numpy as np
-import numpy.testing
 import nose.tools
 
-from hyperspy.hspy import *
+import hyperspy.hspy as hs
+
+
+class TestModel:
+
+    def setUp(self):
+        s = hs.signals.Spectrum(np.empty(1))
+        m = hs.create_model(s)
+        self.model = m
+
+    def test_access_component_by_name(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        nose.tools.assert_is(m["test"], g2)
+
+    def test_access_component_by_index(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        nose.tools.assert_is(m[1], g2)
+
+    def test_component_name_when_append(self):
+        m = self.model
+        gs = [
+            hs.components.Gaussian(), hs.components.Gaussian(), hs.components.Gaussian()]
+        m.extend(gs)
+        nose.tools.assert_is(m['Gaussian'], gs[0])
+        nose.tools.assert_is(m['Gaussian_0'], gs[1])
+        nose.tools.assert_is(m['Gaussian_1'], gs[2])
+
+    @nose.tools.raises(ValueError)
+    def test_several_component_with_same_name(self):
+        m = self.model
+        gs = [
+            hs.components.Gaussian(), hs.components.Gaussian(), hs.components.Gaussian()]
+        m.extend(gs)
+        m[0]._name = "hs.components.Gaussian"
+        m[1]._name = "hs.components.Gaussian"
+        m[2]._name = "hs.components.Gaussian"
+        m['Gaussian']
+
+    @nose.tools.raises(ValueError)
+    def test_no_component_with_that_name(self):
+        m = self.model
+        m['Voigt']
+
+    @nose.tools.raises(ValueError)
+    def test_component_already_in_model(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        m.extend((g1, g1))
+
+    def test_remove_component(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        m.append(g1)
+        m.remove(g1)
+        nose.tools.assert_equal(len(m), 0)
+
+    def test_remove_component_by_index(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        m.append(g1)
+        m.remove(0)
+        nose.tools.assert_equal(len(m), 0)
+
+    def test_remove_component_by_name(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        m.append(g1)
+        m.remove(g1.name)
+        nose.tools.assert_equal(len(m), 0)
+
+    def test_get_component_by_name(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        nose.tools.assert_is(m._get_component("test"), g2)
+
+    def test_get_component_by_index(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        nose.tools.assert_is(m._get_component(1), g2)
+
+    def test_get_component_by_component(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        nose.tools.assert_is(m._get_component(g2), g2)
+
+    @nose.tools.raises(ValueError)
+    def test_get_component_wrong(self):
+        m = self.model
+        g1 = hs.components.Gaussian()
+        g2 = hs.components.Gaussian()
+        g2.name = "test"
+        m.extend((g1, g2))
+        m._get_component(1.2)
 
 
 class TestModelFitBinned:
 
     def setUp(self):
         np.random.seed(1)
-        s = signals.Spectrum(
+        s = hs.signals.Spectrum(
             np.random.normal(
                 scale=2,
                 size=10000)).get_histogram()
         s.metadata.Signal.binned = True
-        g = components.Gaussian()
-        m = create_model(s)
+        g = hs.components.Gaussian()
+        m = hs.create_model(s)
         m.append(g)
         g.sigma.value = 1
         g.centre.value = 0.5
@@ -87,14 +195,14 @@ class TestModelWeighted:
 
     def setUp(self):
         np.random.seed(1)
-        s = signals.SpectrumSimulation(np.arange(10, 100, 0.1))
+        s = hs.signals.SpectrumSimulation(np.arange(10, 100, 0.1))
         s.metadata.set_item("Signal.Noise_properties.variance",
-                            signals.Spectrum(np.arange(10, 100, 0.01)))
+                            hs.signals.Spectrum(np.arange(10, 100, 0.01)))
         s.axes_manager[0].scale = 0.1
         s.axes_manager[0].offset = 10
         s.add_poissonian_noise()
-        m = create_model(s)
-        m.append(components.Polynomial(1))
+        m = hs.create_model(s)
+        m.append(hs.components.Polynomial(1))
         self.m = m
 
     def test_fit_leastsq_binned(self):
@@ -178,9 +286,9 @@ class TestModelWeighted:
 class TestModelScalarVariance:
 
     def setUp(self):
-        s = signals.SpectrumSimulation(np.ones(100))
-        m = create_model(s)
-        m.append(components.Offset())
+        s = hs.signals.SpectrumSimulation(np.ones(100))
+        m = hs.create_model(s)
+        m.append(hs.components.Offset())
         self.s = s
         self.m = m
 
@@ -216,7 +324,7 @@ class TestModelScalarVariance:
         self.m.fit(fitter="leastsq", method="ls")
         nose.tools.assert_almost_equals(self.m.red_chisq.data, 0.79949135)
 
-    def test_std1_red_chisq(self):
+    def test_std1_red_chisq_in_range(self):
         std = 1
         self.m.set_signal_range(10, 50)
         np.random.seed(1)
@@ -229,7 +337,7 @@ class TestModelScalarVariance:
 class TestModelSignalVariance:
 
     def setUp(self):
-        variance = signals.SpectrumSimulation(
+        variance = hs.signals.SpectrumSimulation(
             np.arange(
                 100, 300).reshape(
                 (2, 100)))
@@ -240,8 +348,8 @@ class TestModelSignalVariance:
         s.add_poissonian_noise()
         s.metadata.set_item("Signal.Noise_properties.variance",
                             variance + std ** 2)
-        m = create_model(s)
-        m.append(components.Polynomial(order=1))
+        m = hs.create_model(s)
+        m.append(hs.components.Polynomial(order=1))
         self.s = s
         self.m = m
 
@@ -256,11 +364,11 @@ class TestModelSignalVariance:
 class TestMultifit:
 
     def setUp(self):
-        s = signals.Spectrum(np.empty((2, 200)))
+        s = hs.signals.Spectrum(np.empty((2, 200)))
         s.axes_manager[-1].offset = 1
         s.data[:] = 2 * s.axes_manager[-1].axis ** (-3)
-        m = create_model(s)
-        m.append(components.PowerLaw())
+        m = hs.create_model(s)
+        m.append(hs.components.PowerLaw())
         m[0].A.value = 2
         m[0].r.value = 2
         m.store_current_values()
@@ -286,3 +394,47 @@ class TestMultifit:
                                              [3., 3.])
         np.testing.assert_array_almost_equal(self.m[0].A.map['values'],
                                              [2., 2.])
+
+
+class TestStoreCurrentValues:
+
+    def setUp(self):
+        self.m = hs.create_model(hs.signals.Spectrum(np.arange(10)))
+        self.o = hs.components.Offset()
+        self.m.append(self.o)
+
+    def test_active(self):
+        self.o.offset.value = 2
+        self.o.offset.std = 3
+        self.m.store_current_values()
+        nose.tools.assert_equal(self.o.offset.map["values"][0], 2)
+        nose.tools.assert_equal(self.o.offset.map["is_set"][0], True)
+
+    def test_not_active(self):
+        self.o.active = False
+        self.o.offset.value = 2
+        self.o.offset.std = 3
+        self.m.store_current_values()
+        nose.tools.assert_not_equal(self.o.offset.map["values"][0], 2)
+
+
+class TestSetCurrentValuesTo:
+
+    def setUp(self):
+        self.m = hs.create_model(hs.signals.Spectrum(
+            np.arange(10).reshape(2, 5)))
+        self.comps = [hs.components.Offset(), hs.components.Offset()]
+        self.m.extend(self.comps)
+
+    def test_set_all(self):
+        for c in self.comps:
+            c.offset.value = 2
+        self.m.assign_current_values_to_all()
+        nose.tools.assert_true((self.comps[0].offset.map["values"] == 2).all())
+        nose.tools.assert_true((self.comps[1].offset.map["values"] == 2).all())
+
+    def test_set_1(self):
+        self.comps[1].offset.value = 2
+        self.m.assign_current_values_to_all([self.comps[1]])
+        nose.tools.assert_true((self.comps[0].offset.map["values"] != 2).all())
+        nose.tools.assert_true((self.comps[1].offset.map["values"] == 2).all())
