@@ -16,11 +16,9 @@
 # along with HyperSpy. If not, see <http://www.gnu.org/licenses/>.
 
 
-import os
-
 import numpy as np
 
-from nose.tools import assert_true, assert_equal, assert_not_equal
+from nose.tools import assert_true
 from hyperspy._signals.spectrum import Spectrum
 from hyperspy.hspy import create_model
 from hyperspy.components import Gaussian
@@ -62,7 +60,7 @@ class TestSetParameterInModel:
         assert_true(np.all(g2.A.map['values'] == 20))
         assert_true(np.all(g3.A.map['values'] == 0))
 
-    def test_set_parameter_value2(self):
+    def test_set_parameter_value3(self):
         m = self.model
         g1 = self.g1
         g2 = self.g2
@@ -72,3 +70,45 @@ class TestSetParameterInModel:
         assert_true(np.all(g1.A.map['values'] == 0))
         assert_true(np.all(g2.A.map['values'] == 0))
         assert_true(np.all(g3.A.map['values'] == 0))
+
+    def test_set_active_value1(self):
+        m = self.model
+        g1 = self.g1
+        g2 = self.g2
+        g3 = self.g3
+        g1.active_is_multidimensional = True
+        g2.active_is_multidimensional = True
+        g3.active_is_multidimensional = True
+        m.set_component_active_value(False)
+        assert_true(np.all(np.logical_not(g1._active_array)))
+        assert_true(np.all(np.logical_not(g2._active_array)))
+        assert_true(np.all(np.logical_not(g3._active_array)))
+
+    def test_set_active_value2(self):
+        m = self.model
+        g1 = self.g1
+        g2 = self.g2
+        g3 = self.g3
+        g1.active_is_multidimensional = True
+        g2.active_is_multidimensional = True
+        g3.active_is_multidimensional = True
+        m.set_component_active_value(False, component_list=[g1, g2])
+        assert_true(np.all(np.logical_not(g1._active_array)))
+        assert_true(np.all(np.logical_not(g2._active_array)))
+        assert_true(np.all(g3._active_array))
+
+    def test_set_active_value3(self):
+        m = self.model
+        g1 = self.g1
+        g2 = self.g2
+        g3 = self.g3
+        g1.active_is_multidimensional = True
+        g2.active_is_multidimensional = True
+        g3.active_is_multidimensional = True
+        m.set_component_active_value(False,
+                                     component_list=[g1],
+                                     only_current=True)
+        g1._active_array[0][0] = not g1._active_array[0][0]
+        assert_true(np.all(g1._active_array))
+        assert_true(np.all(g2._active_array))
+        assert_true(np.all(g3._active_array))
