@@ -1,11 +1,6 @@
 import numpy as np
-from nose.tools import (
-    assert_true,
-    assert_equal,
-    assert_not_equal,
-    raises)
+from nose.tools import assert_equal
 
-from hyperspy.signal import Signal
 from hyperspy import signals
 
 
