@@ -1,4 +1,4 @@
-from nose.tools import assert_true, assert_equal, raises
+import nose.tools
 import numpy as np
 
 from hyperspy.signals import Spectrum, Image
@@ -11,9 +11,9 @@ class Test2D():
 
     def test_to_image(self):
         im = self.s.to_image()
-        assert_true(isinstance(im, Image))
-        assert_equal(im.data.shape, self.s.data.T.shape)
-        assert_true(im.data.flags["C_CONTIGUOUS"])
+        nose.tools.assert_true(isinstance(im, Image))
+        nose.tools.assert_equal(im.data.shape, self.s.data.T.shape)
+        nose.tools.assert_true(im.data.flags["C_CONTIGUOUS"])
 
 
 class Test3D():
@@ -23,9 +23,9 @@ class Test3D():
 
     def test_to_image(self):
         im = self.s.to_image()
-        assert_true(isinstance(im, Image))
-        assert_equal(im.data.shape, (4, 2, 3))
-        assert_true(im.data.flags["C_CONTIGUOUS"])
+        nose.tools.assert_true(isinstance(im, Image))
+        nose.tools.assert_equal(im.data.shape, (4, 2, 3))
+        nose.tools.assert_true(im.data.flags["C_CONTIGUOUS"])
 
 
 class Test4D():
@@ -35,6 +35,6 @@ class Test4D():
 
     def test_to_image(self):
         im = self.s.to_image()
-        assert_true(isinstance(im, Image))
-        assert_equal(im.data.shape, (5, 2, 3, 4))
-        assert_true(im.data.flags["C_CONTIGUOUS"])
+        nose.tools.assert_true(isinstance(im, Image))
+        nose.tools.assert_equal(im.data.shape, (5, 2, 3, 4))
+        nose.tools.assert_true(im.data.flags["C_CONTIGUOUS"])
